# https://arxiv.org/category_taxonomy
SUBJECTS = [
    "Computer Science",
    "Economics",
    "Electrical Engineering and Systems Science",
    "Mathematics",
    "Physics",
    "Quantitative Biology",
    "Quantitative Finance",
    "Statistics"
    "Astrophysics of Galaxies",
    "Cosmology and Nongalactic Astrophysics",
    "Earth and Planetary Astrophysics",
    "High Energy Astrophysical Phenomena",
    "Instrumentation and Methods for Astrophysics",
    "Solar and Stellar Astrophysics",
    "Disordered Systems and Neural Networks",
    "Materials Science",
    "Mesoscale and Nanoscale Physics",
    "Other Condensed Matter",
    "Quantum Gases",
    "Soft Condensed Matter",
    "Statistical Mechanics",
    "Strongly Correlated Electrons",
    "Superconductivity",
    "Adaptation and Self-Organizing Systems",
    "Cellular Automata and Lattice Gases",
    "Chaotic Dynamics",
    "Exactly Solvable and Integrable Systems",
    "Pattern Formation and Solitons",
    "Accelerator Physics",
    "Applied Physics",
    "Atmospheric and Oceanic Physics",
    "Atomic and Molecular Clusters",
    "Atomic Physics",
    "Biological Physics",
    "Chemical Physics",
    "Classical Physics",
    "Computational Physics",
    "Data Analysis, Statistics and Probability",
    "Fluid Dynamics",
    "General Physics",
    "Geophysics",
    "History and Philosophy of Physics",
    "Instrumentation and Detectors",
    "Medical Physics",
    "Optics",
    "Physics and Society",
    "Physics Education",
    "Plasma Physics",
    "Popular Physics",
    "Space Physics",
    "Algebraic Geometry",
    "Algebraic Topology",
    "Analysis of PDEs",
    "Category Theory",
    "Classical Analysis and ODEs",
    "Combinatorics",
    "Commutative Algebra",
    "Complex Variables",
    "Differential Geometry",
    "Dynamical Systems",
    "Functional Analysis",
    "General Mathematics",
    "General Topology",
    "Geometric Topology",
    "Group Theory",
    "History and Overview",
    "Information Theory",
    "K-Theory and Homology",
    "Logic",
    "Mathematical Physics",
    "Metric Geometry",
    "Number Theory",
    "Numerical Analysis",
    "Operator Algebras",
    "Optimization and Control",
    "Probability",
    "Quantum Algebra",
    "Representation Theory",
    "Rings and Algebras",
    "Spectral Theory",
    "Statistics Theory",
    "Symplectic Geometry",
    "Artificial Intelligence",
    "Computation and Language",
    "Computational Complexity",
    "Computational Engineering, Finance, and Science",
    "Computational Geometry",
    "Computer Science and Game Theory",
    "Computer Vision and Pattern Recognition",
    "Computers and Society",
    "Cryptography and Security",
    "Data Structures and Algorithms",
    "Databases",
    "Digital Libraries",
    "Discrete Mathematics",
    "Distributed, Parallel, and Cluster Computing",
    "Emerging Technologies",
    "Formal Languages and Automata Theory",
    "General Literature",
    "Graphics",
    "Hardware Architecture",
    "Human-Computer Interaction",
    "Information Retrieval",
    "Information Theory",
    "Logic in Computer Science",
    "Machine Learning",
    "Mathematical Software",
    "Multiagent Systems",
    "Multimedia",
    "Networking and Internet Architecture",
    "Neural and Evolutionary Computing",
    "Numerical Analysis",
    "Operating Systems",
    "Other Computer Science",
    "Performance",
    "Programming Languages",
    "Robotics",
    "Social and Information Networks",
    "Software Engineering",
    "Sound",
    "Symbolic Computation",
    "Systems and Control",
    "Biomolecules",
    "Cell Behavior",
    "Genomics",
    "Molecular Networks",
    "Neurons and Cognition",
    "Other Quantitative Biology",
    "Populations and Evolution",
    "Quantitative Methods",
    "Subcellular Processes",
    "Tissues and Organs",
    "Computational Finance",
    "Economics",
    "General Finance",
    "Mathematical Finance",
    "Portfolio Management",
    "Pricing of Securities",
    "Risk Management",
    "Statistical Finance",
    "Trading and Market Microstructure",
    "Applications",
    "Computation",
    "Machine Learning",
    "Methodology",
    "Other Statistics",
    "Statistics Theory",
    "Audio and Speech Processing",
    "Image and Video Processing",
    "Signal Processing",
    "Systems and Control",
    "Econometrics",
    "General Economics",
    "Theoretical Economics",
]
